About

Struct About 

pub struct About {
    pub kind: Option<String>,
    pub storage_quota: Option<StorageQuota>,
    pub drive_themes: Option<Vec<DriveTheme>>,
    pub can_create_drives: Option<bool>,
    pub import_formats: Option<Map<String, Value>>,
    pub export_formats: Option<Map<String, Value>>,
    pub app_installed: Option<bool>,
    pub user: Option<User>,
    pub folder_color_palette: Option<Vec<String>>,
    pub max_import_sizes: Option<Map<String, Value>>,
    pub max_upload_size: Option<String>,
}
Information about the user, the user’s Drive, and system capabilities.

See Google’s documentation for a full list and more detailed information.

Warning

Fields like teamDriveThemes or canCreateTeamDrives are not included in this struct, since they are marked as deprecated in Google’s documentation.

Note

All of the fields of About are an Option since the values that Google’s API will return are dependent on the fields requested.

Fields

kind: Option<String>

Identifies what kind of resource this is. Value: the fixed string “drive#about”.

storage_quota: Option<StorageQuota>

The user’s storage quota limits and usage. All fields are measured in bytes.

drive_themes: Option<Vec<DriveTheme>>

A list of themes that are supported for shared drives.

can_create_drives: Option<bool>

Whether the user can create shared drives.

import_formats: Option<Map<String, Value>>

A map of source MIME type to possible targets for all supported imports.

export_formats: Option<Map<String, Value>>

A map of source MIME type to possible targets for all supported exports.

app_installed: Option<bool>

Whether the user has installed the requesting app.

user: Option<User>

The authenticated user.

folder_color_palette: Option<Vec<String>>

The currently supported folder colors as RGB hex strings.

max_import_sizes: Option<Map<String, Value>>

A map of maximum import sizes by MIME type, in bytes.

max_upload_size: Option<String>

The maximum upload size in bytes.

Implementations

Source

impl About

pub fn new() -> Self

Creates a new, empty instance of this struct.