pub struct App {Show 24 fields
pub name: Option<String>,
pub object_type: Option<String>,
pub supports_create: Option<bool>,
pub product_url: Option<String>,
pub primary_mime_types: Option<Vec<String>>,
pub secondary_mime_types: Option<Vec<String>>,
pub primary_file_extensions: Option<Vec<String>>,
pub secondary_file_extensions: Option<Vec<String>>,
pub id: Option<String>,
pub supports_import: Option<bool>,
pub installed: Option<bool>,
pub authorized: Option<bool>,
pub icons: Option<Vec<AppIcon>>,
pub use_by_default: Option<bool>,
pub kind: Option<String>,
pub short_description: Option<String>,
pub long_description: Option<String>,
pub supports_multi_open: Option<bool>,
pub product_id: Option<String>,
pub open_url_template: Option<String>,
pub create_url: Option<String>,
pub create_in_folder_template: Option<String>,
pub supports_offline_create: Option<bool>,
pub has_drive_wide_scope: Option<bool>,
}Expand description
An app that a user has installed.
Contains information about its supported MIME types, file extensions, and other details.
Fields
name: Option<String>The name of the app.
object_type: Option<String>The type of object this app creates such as a Chart.
If empty, the app name should be used instead.
supports_create: Option<bool>Whether this app supports creating objects.
product_url: Option<String>A link to the product listing for this app.
primary_mime_types: Option<Vec<String>>The list of primary MIME types.
secondary_mime_types: Option<Vec<String>>The list of secondary MIME types.
primary_file_extensions: Option<Vec<String>>The list of primary file extensions.
secondary_file_extensions: Option<Vec<String>>The list of secondary file extensions.
id: Option<String>The ID of the app.
supports_import: Option<bool>Whether this app supports importing from Google Docs.
installed: Option<bool>Whether the app is installed.
Whether the app is authorized to access data on the user’s Drive.
icons: Option<Vec<AppIcon>>The various icons for the app.
use_by_default: Option<bool>Whether the app is selected as the default handler for the types it supports.
kind: Option<String>Identifies what kind of resource this is.
This always is drive#app.
short_description: Option<String>A short description of the app.
long_description: Option<String>A long description of the app.
supports_multi_open: Option<bool>Whether this app supports opening more than one file.
product_id: Option<String>The ID of the product listing for this app.
open_url_template: Option<String>The template URL for opening files with this app.
The template contains {ids} or {exportIds} to be replaced by the
actual file IDs.
For more information, see Google’s Open Files documentation.
create_url: Option<String>The URL to create a file with this app.
create_in_folder_template: Option<String>The template URL to create a file with this app in a given folder.
The template contains the {folderId} to be replaced by the folder ID
house the new file.
supports_offline_create: Option<bool>Whether this app supports creating files when offline.
has_drive_wide_scope: Option<bool>Whether the app has Drive-wide scope.
An app with Drive-wide scope can access all files in the user’s Drive.