pub struct AppIcon {
pub size: Option<i64>,
pub category: Option<String>,
pub icon_url: Option<String>,
}Expand description
An icon for an app.
Fields
size: Option<i64>Size of the icon.
Represented as the maximum of the width and height.
category: Option<String>Category of the icon.
Allowed values are:
application: The icon for the application.document: The icon for a file associated with the app.documentShared: The icon for a shared file associated with the app.
icon_url: Option<String>URL for the icon.
Implementations