pub struct AppList {
pub default_app_ids: Option<Vec<String>>,
pub kind: Option<String>,
pub self_link: Option<String>,
pub items: Option<Vec<App>>,
}Expand description
A list of apps which the user has installed.
Fields
default_app_ids: Option<Vec<String>>The list of app IDs that the user has specified to use by default.
The list is in reverse-priority order (lowest to highest).
kind: Option<String>Identifies what kind of resource this is.
This always is drive#appList.
self_link: Option<String>A link back to this list.
items: Option<Vec<App>>The list of apps.
Implementations