BackgroundImageFile

Struct BackgroundImageFile 

pub struct BackgroundImageFile {
    pub id: Option<String>,
    pub x_coordinate: Option<f32>,
    pub y_coordinate: Option<f32>,
    pub width: Option<f32>,
}
Background image for a shared drive.

Fields

id: Option<String>

The ID of an image file in Google Drive to use for the background image.

x_coordinate: Option<f32>

The X coordinate of the upper left corner of the cropping area in the background image.

This is a value in the closed range of 0 to 1. This value represents the horizontal distance from the left side of the entire image to the left side of the cropping area divided by the width of the entire image.

y_coordinate: Option<f32>

The Y coordinate of the upper left corner of the cropping area in the background image.

This is a value in the closed range of 0 to 1. This value represents the vertical distance from the top side of the entire image to the top side of the cropping area divided by the height of the entire image.

width: Option<f32>

The width of the cropped image in the closed range of 0 to 1.

This value represents the width of the cropped image divided by the width of the entire image. The height is computed by applying a width to height aspect ratio of 80 to 9. The resulting image must be at least 1280 pixels wide and 144 pixels high.

Implementations

Source

impl BackgroundImageFile

pub fn new() -> Self

Creates a new, empty instance of this struct.