pub struct Change {
pub kind: Option<String>,
pub removed: Option<bool>,
pub file: Option<File>,
pub file_id: Option<String>,
pub time: Option<String>,
pub drive_id: Option<String>,
pub change_type: Option<String>,
pub drive: Option<DriveInfo>,
}Expand description
A change to a file or shared drive.
Fields
kind: Option<String>Identifies what kind of resource this is.
This is always drive#change.
removed: Option<bool>Whether the file or shared drive has been removed from this list of changes, for example by deletion or loss of access.
file: Option<File>The updated state of the file.
Present if the type is file and the file has not been removed from this list of changes.
file_id: Option<String>The ID of the file which has changed.
time: Option<String>The time of this change (RFC 3339 date-time).
drive_id: Option<String>The ID of the shared drive associated with this change.
change_type: Option<String>The type of the change.
Possible values are file and drive.
drive: Option<DriveInfo>The updated state of the shared drive.
Present if the change_type is drive, the user
is still a member of the shared drive, and the shared drive has not been
deleted.
Implementations