pub struct ChangeList {
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub new_start_page_token: Option<String>,
pub changes: Option<Vec<Change>>,
}Expand description
A list of changes for a user.
Fields
kind: Option<String>Identifies what kind of resource this is.
This is always drive#changeList.
next_page_token: Option<String>The page token for the next page of changes.
This will be absent if the end of the changes list has been reached. The page token doesn’t expire.
new_start_page_token: Option<String>The starting page token for future changes.
This will be present only if the end of the current changes list has been reached. The page token doesn’t expire.
changes: Option<Vec<Change>>The list of changes.
If next_page_token is populated, then
this list may be incomplete and an additional page of results should be
fetched.
Implementations
Sourceimpl ChangeList
impl ChangeList