pub struct Channel {
pub payload: Option<bool>,
pub id: Option<String>,
pub resource_id: Option<String>,
pub resource_uri: Option<String>,
pub token: Option<String>,
pub expiration: Option<String>,
pub channel_type: Option<String>,
pub address: Option<String>,
pub params: Option<Map<String, Value>>,
pub kind: Option<String>,
}Expand description
A notification channel used to watch for resource changes.
Warning:
The field type is renamed to channel_type as the word type is a reserved keyword in Rust.
Fields
payload: Option<bool>A Boolean value to indicate whether payload is wanted.
id: Option<String>A UUID or similar unique string that identifies this channel.
resource_id: Option<String>An opaque ID that identifies the resource being watched on this channel.
Stable across different API versions.
resource_uri: Option<String>A version-specific identifier for the watched resource.
token: Option<String>An arbitrary string delivered to the target address with each notification delivered over this channel.
expiration: Option<String>Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds.
channel_type: Option<String>The type of delivery mechanism used for this channel.
Valid values are web_hook or webhook.
address: Option<String>The address where notifications are delivered for this channel.
params: Option<Map<String, Value>>Additional parameters controlling delivery channel behavior.
kind: Option<String>Identifies this as a notification channel, which is api#channel.