pub struct CommentList {
pub kind: Option<String>,
pub comments: Option<Vec<Comment>>,
pub next_page_token: Option<String>,
}Expand description
A list of comments on a file.
Fields
kind: Option<String>Identifies what kind of resource this is.
This is always drive#commentList.
comments: Option<Vec<Comment>>The list of comments.
If next_page_token is populated, then
this list may be incomplete and an additional page of results should be
fetched.
next_page_token: Option<String>The page token for the next page of comments.
This will be absent if the end of the comments list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. The page token is typically valid for several hours. However, if new items are added or removed, your expected results might differ.
Implementations
Sourceimpl CommentList
impl CommentList