pub struct ContentHints {
pub indexable_text: Option<String>,
pub thumbnail: Option<Thumbnail>,
}Expand description
Additional information about the content of the file.
Fields
indexable_text: Option<String>Text to be indexed for the file to improve fullText queries. This is limited to 128KB in length and may contain HTML elements.
thumbnail: Option<Thumbnail>A thumbnail for the file. This will only be used if Google Drive cannot generate a standard thumbnail.
Implementations
Sourceimpl ContentHints
impl ContentHints