pub struct DriveCapabilities {Show 20 fields
pub can_add_children: Option<bool>,
pub can_comment: Option<bool>,
pub can_copy: Option<bool>,
pub can_delete_drive: Option<bool>,
pub can_download: Option<bool>,
pub can_edit: Option<bool>,
pub can_list_children: Option<bool>,
pub can_manage_members: Option<bool>,
pub can_read_revisions: Option<bool>,
pub can_rename: Option<bool>,
pub can_rename_drive: Option<bool>,
pub can_change_drive_background: Option<bool>,
pub can_share: Option<bool>,
pub can_change_copy_requires_writer_permission_restriction: Option<bool>,
pub can_change_domain_users_only_restriction: Option<bool>,
pub can_change_drive_members_only_restriction: Option<bool>,
pub can_change_sharing_folders_requires_organizer_permission_restriction: Option<bool>,
pub can_reset_drive_restrictions: Option<bool>,
pub can_delete_children: Option<bool>,
pub can_trash_children: Option<bool>,
}Expand description
Capabilities the current user has on a shared drive.
Each capability corresponds to a fine-grained action that a user may take.
Fields
can_add_children: Option<bool>Whether the current user can add children to folders in this shared drive.
can_comment: Option<bool>Whether the current user can comment on files in this shared drive.
can_copy: Option<bool>Whether the current user can copy files in this shared drive.
can_delete_drive: Option<bool>Whether the current user can delete this shared drive.
Attempting to delete the shared drive may still fail if there are untrashed items inside the shared drive.
can_download: Option<bool>Whether the current user can download files in this shared drive.
can_edit: Option<bool>Whether the current user can edit files in this shared drive
can_list_children: Option<bool>Whether the current user can list the children of folders in this shared drive.
can_manage_members: Option<bool>Whether the current user can add members to this shared drive or remove them or change their role.
can_read_revisions: Option<bool>Whether the current user can read the revisions resource of files in this shared drive.
can_rename: Option<bool>Whether the current user can rename files or folders in this shared drive.
can_rename_drive: Option<bool>Whether the current user can rename this shared drive.
can_change_drive_background: Option<bool>Whether the current user can change the background of this shared drive.
Whether the current user can share files or folders in this shared drive.
can_change_copy_requires_writer_permission_restriction: Option<bool>Whether the current user can change the copyRequiresWriterPermission
restriction of this shared drive.
can_change_domain_users_only_restriction: Option<bool>Whether the current user can change the domainUsersOnly restriction
of this shared drive.
can_change_drive_members_only_restriction: Option<bool>Whether the current user can change the driveMembersOnly restriction of this shared drive.
can_change_sharing_folders_requires_organizer_permission_restriction: Option<bool>Whether the current user can change the
sharingFoldersRequiresOrganizerPermission restriction of this shared
drive.
can_reset_drive_restrictions: Option<bool>Whether the current user can reset the shared drive restrictions to defaults.
can_delete_children: Option<bool>Whether the current user can delete children from folders in this shared drive.
can_trash_children: Option<bool>Whether the current user can trash children from folders in this shared drive.
Implementations