pub struct FieldModification {
pub field_id: Option<String>,
pub kind: Option<String>,
pub set_date_values: Option<Vec<String>>,
pub set_text_values: Option<Vec<String>>,
pub set_selection_values: Option<Vec<String>>,
pub set_integer_values: Option<Vec<String>>,
pub set_user_values: Option<Vec<String>>,
pub unset_values: Option<bool>,
}Expand description
A modification to a Label’s field.
Fields
field_id: Option<String>The ID of the field to be modified.
kind: Option<String>This is always drive#labelFieldModification.
set_date_values: Option<Vec<String>>Replaces the value of a date field with these new values.
The string must be in the RFC 3339 full-date format: YYYY-MM-DD.
set_text_values: Option<Vec<String>>Sets the value of a text field.
set_selection_values: Option<Vec<String>>Replaces a selection field with these new values.
set_integer_values: Option<Vec<String>>Replaces the value of an integer field with these new values.
set_user_values: Option<Vec<String>>Replaces a user field with these new values.
The values must be valid email addresses.
unset_values: Option<bool>Unsets the values for this field.
Implementations