All of the fields of FileList are an Option<T> since the values that
Google’s API will return are dependent on the
fields requested, by
default all fields will be requested but if you change this value only the
specified fields will be Some<T>, the rest will be None.
This will be absent if the end of the files list has been reached. If the token is rejected for any reason, it should be
discarded, and pagination should be restarted from the first page of results. The page token is typically valid for
several hours. However, if new items are added or removed, your expected results might differ.
If true, then some search results might be missing, since all documents were not searched. This can occur when
searching multiple drives with the allDrives corpora, but all corpora couldn’t be searched. When this happens, it’s
suggested that clients narrow their query by choosing a different corpus such as user or drive.