pub struct ImageMediaMetadata {Show 21 fields
pub flash_used: Option<bool>,
pub metering_mode: Option<String>,
pub sensor: Option<String>,
pub exposure_mode: Option<String>,
pub color_space: Option<String>,
pub white_balance: Option<String>,
pub width: Option<i64>,
pub height: Option<i64>,
pub location: Option<Location>,
pub rotation: Option<i64>,
pub time: Option<String>,
pub camera_make: Option<String>,
pub camera_model: Option<String>,
pub exposure_time: Option<f64>,
pub aperture: Option<f64>,
pub focal_length: Option<f64>,
pub iso_speed: Option<i64>,
pub exposure_bias: Option<f64>,
pub max_aperture_value: Option<f64>,
pub subject_distance: Option<i64>,
pub lens: Option<String>,
}Expand description
Additional metadata about image media, if available.
Fields
flash_used: Option<bool>Whether a flash was used to create the photo.
metering_mode: Option<String>The metering mode used to create the photo.
sensor: Option<String>The type of sensor used to create the photo.
exposure_mode: Option<String>The exposure mode used to create the photo.
color_space: Option<String>The color space of the photo.
white_balance: Option<String>The white balance mode used to create the photo.
width: Option<i64>The width of the image in pixels.
height: Option<i64>The height of the image in pixels.
location: Option<Location>Geographic location information stored in the image.
rotation: Option<i64>The number of clockwise 90 degree rotations applied from the image’s original orientation.
time: Option<String>The date and time the photo was taken (EXIF DateTime).
camera_make: Option<String>The make of the camera used to create the photo.
camera_model: Option<String>The model of the camera used to create the photo.
exposure_time: Option<f64>The length of the exposure, in seconds.
aperture: Option<f64>The aperture used to create the photo (f-number).
focal_length: Option<f64>The focal length used to create the photo, in millimeters.
iso_speed: Option<i64>The ISO speed used to create the photo.
exposure_bias: Option<f64>The exposure bias of the photo (APEX value).
max_aperture_value: Option<f64>The smallest f-number of the lens at the focal length used to create the photo (APEX value).
subject_distance: Option<i64>The distance to the subject of the photo, in meters.
lens: Option<String>The lens used to create the photo.
Implementations