pub struct LabelList {
pub next_page_token: Option<String>,
pub kind: Option<String>,
pub labels: Option<Vec<Label>>,
}Expand description
Fields
next_page_token: Option<String>The page token for the next page of files.
This will be absent if the end of the files list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. The page token is typically valid for several hours. However, if new items are added or removed, your expected results might differ.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “drive#labelList”.
labels: Option<Vec<Label>>The list of labels.
If next_page_token is populated, then this list may be incomplete and an additional page
of results should be fetched.
Implementations