pub struct PermissionDetails {
pub permission_type: Option<String>,
pub inherited_from: Option<String>,
pub role: Option<String>,
pub inherited: Option<bool>,
}Expand description
Details of whether the permissions on this shared drive item are inherited or directly on this item.
This is an output-only field which is present only for shared drive items.
Fields
permission_type: Option<String>The permission type for this user.
While new values may be added in future, the following are currently possible:
filemember
inherited_from: Option<String>The ID of the item from which this permission is inherited.
role: Option<String>The primary role for this user.
While new values may be added in the future, the following are currently possible:
organizerfileOrganizerwritercommenterreader
inherited: Option<bool>Whether this permission is inherited.
Implementations