pub struct PermissionList {
pub next_page_token: Option<String>,
pub kind: Option<String>,
pub permissions: Option<Vec<Permission>>,
}Expand description
A list of permissions for a file.
Fields
next_page_token: Option<String>The page token for the next page of permissions.
This will be absent if the end of the list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. The page token is typically valid for several hours. However, if new items are added or removed, your expected results might differ.
kind: Option<String>Identifies what kind of resource this is.
This is always drive#permissionList.
permissions: Option<Vec<Permission>>The list of shared drives.
If next_page_token is populated,
then this list may be incomplete and an additional page of results
should be fetched.
Implementations