pub struct QuotedFileContent {
pub mime_type: Option<String>,
pub value: Option<String>,
}Expand description
The file content to which the comment refers, typically within the anchor region.
For a text file, for example, this would be the text at the location of the comment.
Fields
mime_type: Option<String>The MIME type of the quoted content.
value: Option<String>The quoted content itself.
This is interpreted as plain text if set through the API.
Implementations