pub struct Reply {
pub id: Option<String>,
pub kind: Option<String>,
pub created_time: Option<String>,
pub modified_time: Option<String>,
pub action: Option<String>,
pub author: Option<User>,
pub deleted: Option<bool>,
pub html_content: Option<String>,
pub content: Option<String>,
}Expand description
A reply to a comment on a file.
Fields
id: Option<String>The ID of the reply.
kind: Option<String>Identifies what kind of resource this is.
This is always drive#reply.
created_time: Option<String>The time at which the comment was created (RFC 3339 date-time).
modified_time: Option<String>The last time the comment or any of its replies was modified (RFC 3339 date-time).
action: Option<String>The action the reply performed to the parent comment.
Valid values are:
resolvereopen
The author of the reply.
The author’s email address and permission ID will not be populated.
deleted: Option<bool>Whether the reply has been deleted.
A deleted reply has no content.
html_content: Option<String>The content of the reply with HTML formatting.
content: Option<String>The plain text content of the reply.
This field is used for setting the content, while
html_content should be displayed. This is
required on creates if no action is specified.
Implementations