pub struct Revision {Show 14 fields
pub id: Option<String>,
pub mime_type: Option<String>,
pub kind: Option<String>,
pub published: Option<bool>,
pub export_links: Option<Map<String, Value>>,
pub keep_forever: Option<bool>,
pub md5_checksum: Option<String>,
pub modified_time: Option<String>,
pub publish_auto: Option<bool>,
pub published_outside_domain: Option<bool>,
pub published_link: Option<String>,
pub size: Option<String>,
pub original_filename: Option<String>,
pub last_modifying_user: Option<User>,
}Expand description
The metadata for a revision to a file.
Fields
id: Option<String>The ID of the revision.
mime_type: Option<String>The MIME type of the revision.
kind: Option<String>Identifies what kind of resource this is.
This is always drive#revision.
published: Option<bool>Whether this revision is published.
This is only applicable to Docs Editors files.
export_links: Option<Map<String, Value>>Links for exporting Docs Editors files to specific formats.
keep_forever: Option<bool>Whether to keep this revision forever, even if it is no longer the head revision.
If not set, the revision will be automatically purged 30 days after newer content is uploaded. This can be set on a maximum of 200 revisions for a file.
md5_checksum: Option<String>The MD5 checksum of the revision’s content.
This is only applicable to files with binary content in Drive.
modified_time: Option<String>The last time the revision was modified (RFC 3339 date-time).
publish_auto: Option<bool>Whether subsequent revisions will be automatically republished.
This is only applicable to Docs Editors files.
published_outside_domain: Option<bool>Whether this revision is published outside the domain.
This is only applicable to Docs Editors files.
published_link: Option<String>A link to the published revision.
This is only populated for Google Sites files.
size: Option<String>The size of the revision’s content in bytes.
This is only applicable to files with binary content in Drive.
original_filename: Option<String>The original filename used to create this revision.
This is only applicable to files with binary content in Drive.
last_modifying_user: Option<User>The last user to modify this revision.
Implementations