pub struct User {
pub display_name: Option<String>,
pub kind: Option<String>,
pub me: Option<bool>,
pub permission_id: Option<String>,
pub email_address: Option<String>,
pub photo_link: Option<String>,
}Expand description
Information about a Drive user.
See Google’s documentation for a full list and more detailed information.
Fields
display_name: Option<String>A plain text displayable name for this user.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “drive#user”.
me: Option<bool>Whether this user is the requesting user.
permission_id: Option<String>The user’s ID as visible in Permission resources.
email_address: Option<String>The email address of the user. This may not be present in certain contexts if the user has not made their email address visible to the requester.
photo_link: Option<String>A link to the user’s profile photo, if available.
Implementations