pub struct GetStartPageTokenRequest { /* private fields */ }Expand description
A request builder to get the starting pageToken for listing future
changes.
Implementations
Sourceimpl GetStartPageTokenRequest
impl GetStartPageTokenRequest
Sourcepub fn new(credentials: &Credentials) -> Self
pub fn new(credentials: &Credentials) -> Self
Creates a new GetStartPageTokenRequest builder, authorized with the given Credentials.
Sourcepub fn fields<T>(self, value: T) -> Self
pub fn fields<T>(self, value: T) -> Self
You can set this parameter to return the exact fields you need, and improve performance in your method call.
Note:
By default, the server sends back a set of fields specific to the resource being queried. For example, the files.get method might only return the id, name, and mimeType for the files resource. The permissions.get method returns a different set of default fields for a permissions resource.
See Google’s documentation
Sourcepub fn drive_id<T>(self, value: T) -> Self
pub fn drive_id<T>(self, value: T) -> Self
The ID of the shared drive for which the starting pageToken for listing future changes from that shared drive will be returned.
Sourcepub fn supports_all_drives<T>(self, value: T) -> Self
pub fn supports_all_drives<T>(self, value: T) -> Self
Whether the requesting application supports both My Drives and shared drives.
Sourceimpl GetStartPageTokenRequest
impl GetStartPageTokenRequest
Sourcepub fn execute(&self) -> Result<String>
pub fn execute(&self) -> Result<String>
Executes this request.
Errors:
- a
UrlParsingerror, if the creation of the request’s URL failed. - a
Requesterror, if unable to send the request or get a body from the response. - a
Responseerror, if the request returned an error response. - a
Jsonerror, if unable to parse the response’s body.