pub struct CreateRequest { /* private fields */ }Expand description
A request builder to create a comment on a file.
Implementations
Sourceimpl CreateRequest
impl CreateRequest
Sourcepub fn new(credentials: &Credentials, file_id: impl AsRef<str>) -> Self
pub fn new(credentials: &Credentials, file_id: impl AsRef<str>) -> Self
Creates a new CreateRequest builder, authorized with the given Credentials.
Sourcepub fn execute(&self) -> Result<Comment>
pub fn execute(&self) -> Result<Comment>
Executes this request.
Errors:
- a
UrlParsingerror, if the creation of the request’s URL failed. - a
Requesterror, if unable to send the request or get a body from the response. - a
Responseerror, if the request returned an error response. - a
Jsonerror, if unable to parse the response’s body to into the return type.
Sourcepub fn fields<T>(self, value: T) -> Self
pub fn fields<T>(self, value: T) -> Self
You can set this parameter to return the exact fields you need, and improve performance in your method call.
Note:
By default, the server sends back a set of fields specific to the resource being queried. For example, the files.get method might only return the id, name, and mimeType for the files resource. The permissions.get method returns a different set of default fields for a permissions resource.
See Google’s documentation