pub struct ListRequest { /* private fields */ }Expand description
A request builder to list the comments on a file.
Implementations
Sourceimpl ListRequest
impl ListRequest
Sourcepub fn new(credentials: &Credentials, file_id: impl AsRef<str>) -> Self
pub fn new(credentials: &Credentials, file_id: impl AsRef<str>) -> Self
Creates a new ListRequest builder, authorized with the given Credentials.
Sourcepub fn execute(&self) -> Result<CommentList>
pub fn execute(&self) -> Result<CommentList>
Executes this request.
Errors:
- a
UrlParsingerror, if the creation of the request’s URL failed. - a
Requesterror, if unable to send the request or get a body from the response. - a
Responseerror, if the request returned an error response. - a
Jsonerror, if unable to parse the response’s body to into the return type.
Sourcepub fn fields<T>(self, value: T) -> Self
pub fn fields<T>(self, value: T) -> Self
You can set this parameter to return the exact fields you need, and improve performance in your method call.
Note:
By default, the server sends back a set of fields specific to the resource being queried. For example, the files.get method might only return the id, name, and mimeType for the files resource. The permissions.get method returns a different set of default fields for a permissions resource.
See Google’s documentation
Sourcepub fn include_deleted<T>(self, value: T) -> Self
pub fn include_deleted<T>(self, value: T) -> Self
Whether to return deleted comments.
Deleted comments will not include their original content.
Sourcepub fn page_token<T>(self, value: T) -> Self
pub fn page_token<T>(self, value: T) -> Self
The token for continuing a previous list request on the next page.
This should be set to the value of
next_page_token from the
previous response.
Sourcepub fn start_modified_time<T>(self, value: T) -> Self
pub fn start_modified_time<T>(self, value: T) -> Self
The minimum value of modifiedTime for the result comments
(RFC 3339 date-time).