About

Struct About 

pub struct About { /* private fields */ }
Information about the user, the user’s Drive, and system capabilities.

Examples:

use drive_v3::{Credentials, Drive};

let credentials_path = "my_credentials.json";
let scopes = ["https://www.googleapis.com/auth/drive.metadata.readonly"];

let credentials = Credentials::from_file(&credentials_path, &scopes)?;
let drive = Drive::new(&credentials);

let my_information = drive.about.get()
    .fields("storageQuota, canCreateDrives, appInstalled")
    .execute()?;

println!("look at all this information:\n{}", my_information);

Implementations

Source

impl About

pub fn new(credentials: &Credentials) -> Self

Creates a new About resource with the given Credentials.

pub fn get(&self) -> GetRequest

Gets information about the user, the user’s Drive, and system capabilities.

See Google’s documentation for more information.

Note:

This request requires you to set the fields parameter.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.appdata
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.metadata
  • https://www.googleapis.com/auth/drive.metadata.readonly
  • https://www.googleapis.com/auth/drive.photos.readonly
  • https://www.googleapis.com/auth/drive.readonly
Examples:
use drive_v3::{Credentials, Drive};

let credentials_path = "my_credentials.json";
let scopes = ["https://www.googleapis.com/auth/drive.metadata.readonly"];

let credentials = Credentials::from_file(&credentials_path, &scopes)?;
let drive = Drive::new(&credentials);

let my_information = drive.about.get()
    .fields("storageQuota, canCreateDrives, appInstalled")
    .execute()?;

println!("look at all this information:\n{}", my_information);