pub struct Apps { /* private fields */ }Expand description
Provides a list of apps that a user has installed.
Contains information about each app’s supported MIME types, file, extensions, and other details.
Some resource methods (such as apps.get) require an app_id.
Use the apps.list method to retrieve the ID for an installed
application.
Examples:
List the apps for a user
let app_list = drive.apps.list().execute()?;
if let Some(apps) = app_list.items {
for app in apps {
println!("{}", app);
}
}Implementations
Sourceimpl Apps
impl Apps
Sourcepub fn new(credentials: &Credentials) -> Self
pub fn new(credentials: &Credentials) -> Self
Creates a new Apps resource with the given Credentials.
Sourcepub fn get<T: AsRef<str>>(&self, app_id: T) -> GetRequest
pub fn get<T: AsRef<str>>(&self, app_id: T) -> GetRequest
Gets a specific app.
See Google’s documentation for more information.
Requires one of the following OAuth scopes:
https://www.googleapis.com/auth/docshttps://www.googleapis.com/auth/drivehttps://www.googleapis.com/auth/drive.appdatahttps://www.googleapis.com/auth/drive.apps.readonlyhttps://www.googleapis.com/auth/drive.filehttps://www.googleapis.com/auth/drive.metadatahttps://www.googleapis.com/auth/drive.metadata.readonlyhttps://www.googleapis.com/auth/drive.readonly
Examples:
let app_id = "some-app-id";
let app = drive.apps.get(&app_id).execute()?;
println!("This is the info of the app:\n{}", app);Sourcepub fn list(&self) -> ListRequest
pub fn list(&self) -> ListRequest
Lists a user’s installed apps.
See Google’s documentation for more information.
Requires the following OAuth scope:
https://www.googleapis.com/auth/drive.apps.readonly
Examples:
let app_list = drive.apps.list().execute()?;
if let Some(apps) = app_list.items {
for app in apps {
println!("{}", app);
}
}Trait Implementations
impl Eq for Apps
impl StructuralPartialEq for Apps