Channels

Struct Channels 

pub struct Channels { /* private fields */ }
A notification channel used to watch for resource changes.

Examples:

use drive_v3::objects::Channel;

// You should use the channel return by requests like files.watch or
// changes.watch
let channel = Channel::new();

let response = drive.channels.stop()
    .channel(&channel)
    .execute();

assert!( response.is_ok() );

Implementations

Source

impl Channels

pub fn new(credentials: &Credentials) -> Self

Creates a new Channels resource with the given Credentials.

pub fn stop(&self) -> StopRequest

Stops watching resources through this channel.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/docs
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.appdata
  • https://www.googleapis.com/auth/drive.apps
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.metadata
  • https://www.googleapis.com/auth/drive.metadata.readonly
  • https://www.googleapis.com/auth/drive.photos.readonly
  • https://www.googleapis.com/auth/drive.readonly
Examples:
use drive_v3::objects::Channel;

// You should use the channel return by requests like files.watch or
// changes.watch
let channel = Channel::new();

let response = drive.channels.stop()
    .channel(&channel)
    .execute();

assert!( response.is_ok() );