Comments

Struct Comments 

pub struct Comments { /* private fields */ }
Comments on a file.

Some resource methods (such as comments.update) require a comment_id. Use the comments.list method to retrieve the ID for a comment in a file.

Examples:

List the comments in a file

let file_id = "some-file-id";

let comment_list = drive.comments.list(&file_id)
    .fields("*") // You must set the fields
    .page_size(10)
    .execute()?;

if let Some(comments) = comment_list.comments {
    for comment in comments {
        println!("{}", comment);
    }
}

Implementations

Source

impl Comments

pub fn new(credentials: &Credentials) -> Self

Creates a new Comments resource with the given Credentials.

pub fn create<T: AsRef<str>>(&self, file_id: T) -> CreateRequest

Creates a comment on a file.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
use drive_v3::objects::Comment;

let comment = Comment {
    content: Some( "this is my comment".to_string() ),
    ..Default::default()
};

let file_id = "some-file-id";

let created_comment = drive.comments.create(&file_id)
    .fields("*")
    .comment(&comment)
    .execute()?;

assert_eq!(created_comment.content, comment.content);
pub fn delete<T, U>(&self, file_id: T, comment_id: U) -> DeleteRequest
where T: AsRef<str>, U: AsRef<str>,

Deletes a comment.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
let file_id = "some-file-id";
let comment_id = "some-comment-id";

let response = drive.comments.delete(&file_id, &comment_id).execute();

assert!( response.is_ok() );
pub fn get<T, U>(&self, file_id: T, comment_id: U) -> GetRequest
where T: AsRef<str>, U: AsRef<str>,

Gets a comment by ID.

See Google’s documentation for more information.

Note:

This request requires you to set the fields parameter.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.readonly
Examples:
let file_id = "some-file-id";
let comment_id = "some-comment-id";

let created_comment = drive.comments.get(&file_id, &comment_id)
    .fields("id, author, createdTime, content") // You must set the fields
    .execute()?;

println!("This is the comment:\n{}", created_comment);
pub fn list<T: AsRef<str>>(&self, file_id: T) -> ListRequest

Lists a file’s comments.

See Google’s documentation for more information.

Note:

This request requires you to set the fields parameter.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.readonly
Examples:
let file_id = "some-file-id";

let comment_list = drive.comments.list(&file_id)
    .fields("*") // You must set the fields
    .page_size(10)
    .execute()?;

if let Some(comments) = comment_list.comments {
    for comment in comments {
        println!("{}", comment);
    }
}
pub fn update<T, U>(&self, file_id: T, comment_id: U) -> UpdateRequest
where T: AsRef<str>, U: AsRef<str>,

Updates a comment with patch semantics.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
use drive_v3::objects::Comment;

let updated_comment = Comment {
    content: Some( "this is the updated content of my comment".to_string() ),
    ..Default::default()
};

let file_id = "some-file-id";
let comment_id = "some-comment-id";

let modified_comment = drive.comments.update(&file_id, &comment_id)
    .fields("*")
    .comment(&updated_comment)
    .execute()?;

assert_eq!(modified_comment.content, updated_comment.content);