Permissions

Struct Permissions 

pub struct Permissions { /* private fields */ }
Permissions for a file.

A permission grants a user, group, domain, or the world access to a file or a folder hierarchy.

Some resource methods (such as permissions.update) require a permission_id. Use the permissions.list method to retrieve the ID for a file, folder, or shared drive.

Examples:

List the permission in a file

let file_id = "some-file-id";
let permission_list = drive.permissions.list(&file_id).execute()?;

if let Some(permissions) = permission_list.permissions {
    for permission in permissions {
        println!("{}", permission);
    }
}

Implementations

Source

impl Permissions

pub fn new(credentials: &Credentials) -> Self

Creates a new Permissions resource with the given Credentials.

pub fn create<T: AsRef<str>>(&self, file_id: T) -> CreateRequest

Creates a permission for a file or shared drive.

See Google’s documentation for more information.

Warning

Concurrent permissions operations on the same file are not supported; only the last update is applied.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
use drive_v3::objects::Permission;

let permission = Permission {
    permission_type: Some( "anyone".to_string() ),
    role: Some( "reader".to_string() ),
    ..Default::default()
};

let file_id = "some-file-id";

let created_permission = drive.permissions.create(&file_id)
    .permission(&permission)
    .execute()?;

assert_eq!(created_permission.permission_type, permission.permission_type);
assert_eq!(created_permission.role, permission.role);
pub fn delete<T, U>(&self, file_id: T, permission_id: U) -> DeleteRequest
where T: AsRef<str>, U: AsRef<str>,

Deletes a permission.

See Google’s documentation for more information.

Warning

Concurrent permissions operations on the same file are not supported; only the last update is applied.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
let file_id = "some-file-id";
let permission_id = "some-permission-id";

let response = drive.permissions.delete(&file_id, &permission_id).execute();

assert!( response.is_ok() );
pub fn get<T, U>(&self, file_id: T, permission_id: U) -> GetRequest
where T: AsRef<str>, U: AsRef<str>,

Gets a permission by ID.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.metadata
  • https://www.googleapis.com/auth/drive.metadata.readonly
  • https://www.googleapis.com/auth/drive.photos.readonly
  • https://www.googleapis.com/auth/drive.readonly
Examples:
let file_id = "some-file-id";
let permission_id = "some-permission-id";

let permission = drive.permissions.get(&file_id, &permission_id).execute()?;

println!("This is the file's permission:\n{}", permission);
pub fn list<T: AsRef<str>>(&self, file_id: T) -> ListRequest

Lists a file’s or shared drive’s permissions.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.metadata
  • https://www.googleapis.com/auth/drive.metadata.readonly
  • https://www.googleapis.com/auth/drive.photos.readonly
  • https://www.googleapis.com/auth/drive.readonly
Examples:
let file_id = "some-file-id";
let permission_list = drive.permissions.list(&file_id).execute()?;

if let Some(permissions) = permission_list.permissions {
    for permission in permissions {
        println!("{}", permission);
    }
}
pub fn update<T, U>(&self, file_id: T, permission_id: U) -> UpdateRequest
where T: AsRef<str>, U: AsRef<str>,

Updates a permission with patch semantics.

See Google’s documentation for more information.

Warning

Concurrent permissions operations on the same file are not supported; only the last update is applied.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
use drive_v3::objects::Permission;

let updated_permission = Permission {
    permission_type: Some( "anyone".to_string() ),
    role: Some( "commenter".to_string() ),
    ..Default::default()
};

let file_id = "some-file-id";
let permission_id = "some-permission-id";

let permission = drive.permissions.update(&file_id, &permission_id)
    .permission(&updated_permission)
    .execute()?;

assert_eq!(permission.permission_type, updated_permission.permission_type);
assert_eq!(permission.role, updated_permission.role);