Replies

Struct Replies 

pub struct Replies { /* private fields */ }
A reply to a comment on a file.

Some resource methods (such as replies.update) require a permission_id. Use the replies.list method to retrieve the ID for a file, folder, or shared drive.

Examples:

List the permission in a file

let file_id = "some-file-id";
let permission_list = drive.permissions.list(&file_id).execute()?;

if let Some(permissions) = permission_list.permissions {
    for permission in permissions {
        println!("{}", permission);
    }
}

Implementations

Source

impl Replies

pub fn new(credentials: &Credentials) -> Self

Creates a new Replies resource with the given Credentials.

pub fn create<T, U>(&self, file_id: T, comment_id: U) -> CreateRequest
where T: AsRef<str>, U: AsRef<str>,

Creates a reply to a comment.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
use drive_v3::objects::Reply;

let reply = Reply {
    content: Some( "my reply content".to_string() ),
    ..Default::default()
};

let file_id = "some-file-id";
let comment_id = "some-comment-id";

let created_reply = drive.replies.create(&file_id, &comment_id)
    .reply(&reply)
    .execute()?;

assert_eq!(created_reply.content, reply.content);
pub fn delete<T, U, V>( &self, file_id: T, comment_id: U, reply_id: V, ) -> DeleteRequest
where T: AsRef<str>, U: AsRef<str>, V: AsRef<str>,

Deletes a reply.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
let file_id = "some-file-id";
let comment_id = "some-comment-id";
let reply_id = "some-reply-id";

let response = drive.replies.delete(&file_id, &comment_id, &reply_id).execute();

assert!( response.is_ok() );
pub fn get<T, U, V>(&self, file_id: T, comment_id: U, reply_id: V) -> GetRequest
where T: AsRef<str>, U: AsRef<str>, V: AsRef<str>,

Gets a reply by ID.

See Google’s documentation for more information.

Note:

This request requires you to set the fields parameter.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.readonly
Examples:
let file_id = "some-file-id";
let comment_id = "some-comment-id";
let reply_id = "some-reply-id";

let reply = drive.replies.get(&file_id, &comment_id, &reply_id)
    .fields("*")
    .execute()?;

println!("This is the comment's reply:\n{}", reply);
pub fn list<T, U>(&self, file_id: T, comment_id: U) -> ListRequest
where T: AsRef<str>, U: AsRef<str>,

Lists a comment’s replies.

See Google’s documentation for more information.

Note:

This request requires you to set the fields parameter.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.readonly
Examples:
let file_id = "some-file-id";
let comment_id = "some-comment-id";

let reply_list = drive.replies.list(&file_id, &comment_id)
    .fields("*")
    .execute()?;

if let Some(replies) = reply_list.replies {
    for reply in replies {
        println!("{}", reply);
    }
}
pub fn update<T, U, V>( &self, file_id: T, comment_id: U, reply_id: V, ) -> UpdateRequest
where T: AsRef<str>, U: AsRef<str>, V: AsRef<str>,

Updates a reply with patch semantics.

See Google’s documentation for more information.

Note:

This request requires you to set the fields parameter.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
use drive_v3::objects::Reply;

let updated_reply = Reply {
    content: Some( "updated content".to_string() ),
    ..Default::default()
};

let file_id = "some-file-id";
let comment_id = "some-comment-id";
let reply_id = "some-reply-id";

let reply = drive.replies.update(&file_id, &comment_id, &reply_id)
    .fields("*")
    .reply(&updated_reply)
    .execute()?;

assert_eq!(reply.content, updated_reply.content);