Revisions

Struct Revisions 

pub struct Revisions { /* private fields */ }
The metadata for a revision to a file.

Some resource methods (such as revisions.update) require a permission_id. Use the revisions.list method to retrieve the ID for a file, folder, or shared drive.

Examples:

List the revisions in a file

let file_id = "some-file-id";

let revision_list = drive.revisions.list(&file_id)
    .execute()?;

if let Some(revisions) = revision_list.revisions {
    for revision in revisions {
        println!("{}", revision);
    }
}

Implementations

Source

impl Revisions

pub fn new(credentials: &Credentials) -> Self

Creates a new Revisions resource with the given Credentials.

pub fn delete<T, U>(&self, file_id: T, revision_id: U) -> DeleteRequest
where T: AsRef<str>, U: AsRef<str>,

Permanently deletes a file version.

You can only delete revisions for files with binary content in Google Drive, like images or videos. Revisions for other files, like Google Docs or Sheets, and the last remaining file version can’t be deleted.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.appdata
  • https://www.googleapis.com/auth/drive.file
Examples:
let file_id = "some-file-id";
let revision_id = "some-revision-id";

let response = drive.revisions.delete(&file_id, &revision_id).execute();

assert!( response.is_ok() );
pub fn get<T, U>(&self, file_id: T, revision_id: U) -> GetRequest
where T: AsRef<str>, U: AsRef<str>,

Gets a revision’s metadata by ID.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.appdata
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.metadata
  • https://www.googleapis.com/auth/drive.metadata.readonly
  • https://www.googleapis.com/auth/drive.photos.readonly
  • https://www.googleapis.com/auth/drive.readonly
Examples:
let file_id = "some-file-id";
let revision_id = "some-revision-id";

let revision = drive.revisions.get(&file_id, &revision_id)
    .fields("*")
    .execute()?;

println!("This is the file's revision metadata:\n{}", revision);
pub fn get_media<T, U>(&self, file_id: T, revision_id: U) -> GetMediaRequest
where T: AsRef<str>, U: AsRef<str>,

Gets a revision’s content by ID.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.appdata
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.metadata
  • https://www.googleapis.com/auth/drive.metadata.readonly
  • https://www.googleapis.com/auth/drive.photos.readonly
  • https://www.googleapis.com/auth/drive.readonly
Examples:
let file_id = "some-file-id";
let revision_id = "some-revision-id";

let file_bytes = drive.revisions.get_media(&file_id, &revision_id)
    // .save_to("my_downloaded_file.txt") // Save the contents to a path
    .execute()?;

let content = String::from_utf8_lossy(&file_bytes);

println!("content: {}", content);
pub fn list<T: AsRef<str>>(&self, file_id: T) -> ListRequest

Lists a file’s revisions.

See Google’s documentation for more information.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.appdata
  • https://www.googleapis.com/auth/drive.file
  • https://www.googleapis.com/auth/drive.metadata
  • https://www.googleapis.com/auth/drive.metadata.readonly
  • https://www.googleapis.com/auth/drive.photos.readonly
  • https://www.googleapis.com/auth/drive.readonly
Examples:
let file_id = "some-file-id";

let revision_list = drive.revisions.list(&file_id)
    .execute()?;

if let Some(revisions) = revision_list.revisions {
    for revision in revisions {
        println!("{}", revision);
    }
}
pub fn update<T, U>(&self, file_id: T, revision_id: U) -> UpdateRequest
where T: AsRef<str>, U: AsRef<str>,

Updates a reply with patch semantics.

See Google’s documentation for more information.

Note:

This request requires you to set the fields parameter.

Requires one of the following OAuth scopes:
  • https://www.googleapis.com/auth/drive
  • https://www.googleapis.com/auth/drive.file
Examples:
use drive_v3::objects::Revision;

let updated_revision = Revision {
    published: Some(false),
    ..Default::default()
};

let file_id = "some-file-id";
let revision_id = "some-revision-id";

let revision = drive.revisions.update(&file_id, &revision_id)
    .fields("*")
    .revision(&updated_revision)
    .execute()?;

assert_eq!(revision.published, updated_revision.published);