ClientSecrets

Struct ClientSecrets 

pub struct ClientSecrets {
    pub client_id: String,
    pub project_id: String,
    pub auth_uri: String,
    pub token_uri: String,
    pub auth_provider_x509_cert_url: String,
    pub client_secret: String,
    pub redirect_uris: Vec<String>,
}
Representation of the client_secrets JSON file that contains the authorization info for your API.

use drive_v3::ClientSecrets;
use drive_v3::AccessToken;

let secrets_path = "my_secrets.json";
let my_client_secrets = ClientSecrets::from_file(&secrets_path)?;

// Now you can requests access tokens with your client secrets
let scopes = ["https://www.googleapis.com/auth/drive.metadata.readonly"];
let my_access_token = AccessToken::request(&my_client_secrets, &scopes)?;

// After getting your token you can make a request (with reqwest for example) using it for authorization
let client = reqwest::blocking::Client::new();
let body = client.get("google-api-endpoint")
    .bearer_auth(&my_access_token.access_token)
    .send()?
    .text()?;

println!("response: {:?}", body);

Fields

client_id: String

Your API’s client ID.

project_id: String

Your API’s project ID.

auth_uri: String

The URI your API can call to request authorization.

token_uri: String

The URI your API can call to request an AccessToken.

auth_provider_x509_cert_url: String

Your API’s certificate provider URL.

client_secret: String

Your API’s client secret.

redirect_uris: Vec<String>

Your API’s redirect URIs.

Implementations

Source

impl ClientSecrets

pub fn from_file<T: AsRef<Path>>(file: T) -> Result<Self>

Gets ClientSecrets from file.

Examples
use drive_v3::ClientSecrets;
use drive_v3::AccessToken;

let secrets_path = "my_secrets.json";
let my_client_secrets = ClientSecrets::from_file(&secrets_path)?;

// Now you can requests access tokens with your client secrets
let scopes = ["https://www.googleapis.com/auth/drive.metadata.readonly"];
let my_access_token = AccessToken::request(&my_client_secrets, &scopes)?;

// After getting your token you can make a request (with reqwest for example) using it for authorization
let client = reqwest::blocking::Client::new();
let body = client.get("google-api-endpoint")
    .bearer_auth(&my_access_token.access_token)
    .send()?
    .text()?;

println!("response: {:?}", body);
Errors
  • an IO error, if the file does not exist.
  • a Json error, if parsing of the file from json failed.
pub fn get_authorization_code<T: AsRef<str>>( &self, scopes: &[T], open_browser: bool, ) -> Result<(String, String)>

Requests and authorization code and it’s associated code_verifier from Google’s API.

This code can be used to request AccessTokens using OAuth2.

Note:

Do not use this function directly in drive_v3 unless you need to make custom requests using an authorization code, instead use the Credentials struct to easily handle authorization.

Examples:

See Google’s official handle OAuth 2.0 responses documentation for information on what to use these codes for.

Errors
  • a HexDecoding or UrlParsing error, if the creation of the code verifier failed.
  • a UrlParsing error, if the creation of the authorization request’s URL failed.
  • a LocalServer or IO error, if the LocalServer failed to listen for incoming requests.
  • a UrlParsing error, if unable to get the query containing the returned authorization code.
  • a MismatchedState error, if the state contained on the response doesn’t match the originally created one.
  • a MismatchedScopes error, if the user didn’t authorize all the requested scopes.
  • a NoAuthorizationCode error, if the response didn’t contain an authorization code.