LocalServer

Struct LocalServer 

pub struct LocalServer {
    pub uri: String,
    pub address: String,
    pub response: String,
}
A local server that can be used to listen for requests.

Examples

use drive_v3::LocalServer;

let local_server = LocalServer::new();
let received_request = local_server.wait_for_request().expect("failed to listen for requests");

// The local server is now running and waiting for a request,
// run "curl http://localhost:7878/my-request-url" to send one.

assert_eq!(received_request, "http://localhost:7878/my-request-url");

Fields

uri: String

URI that a website can make requests to in order for them to be received by the server. (default: “http://localhost:7878”)

address: String

Address where the server listens for requests. (default: “localhost:7878”)

response: String

Response returned by the server after receiving a request. (default: “request processed!”)

Implementations

Source

impl LocalServer

pub fn new() -> Self

Creates a new LocalServer with default values.

pub fn at<T: AsRef<str>>(self, address: T, port: usize) -> Self

Sets the address and port values for a LocalServer.

Examples
use drive_v3::LocalServer;

let local_server = LocalServer::new().at("127.0.0.1", 8080);

assert_eq!(local_server.uri, "http://127.0.0.1:8080");
assert_eq!(local_server.address, "127.0.0.1:8080");
pub fn with_response<T: AsRef<str>>(self, response: T) -> Self

Sets the response that the LocalServer will return after successfully receiving a request.

Examples
use drive_v3::LocalServer;

let local_server = LocalServer::new().with_response("this is my response");

assert_eq!( local_server.response, String::from("this is my response") )
pub fn wait_for_request(&self) -> Result<String>

Runs a LocalServer and binds a listener to its address, after receiving a request the server will close and return the URI of the received request.

Examples
use drive_v3::LocalServer;

let local_server = LocalServer::new();
let received_request = local_server.wait_for_request()?;

// The local server is now running and waiting for a request,
// run "curl http://localhost:7878/my-request-url" to send one.

assert_eq!(received_request, "http://localhost:7878/my-request-url");
Errors
  • an IO error, if the server fails to to bind a TCP listener its address or if the incoming request is invalid.
  • a LocalServer error, if the LocalServer failed to listen for incoming requests.