pub enum UploadType {
Media,
Multipart,
Resumable,
}Expand description
The type of upload request to the /upload URI.
If you are uploading data with an /upload URI, this field is required.
If you are creating a metadata-only file, this field is not required.
Variants
Media
A simple upload which allows you to upload a file without supplying its metadata.
When you perform a simple upload, basic metadata is created and some attributes are inferred from the file, such as the
mime_type or modified_time. You can use a simple upload in
cases where you have small files and file metadata isn’t important.
Multipart
A multipart upload which allows to upload metadata and data in the same request.
Use this option if the data you send is small enough to upload again, in its entirety, if the connection fails.
Resumable
A resumable upload which allows you to resume an upload operation after a communication failure interrupts the flow of data.
Because you don’t have to restart large file uploads from the start, resumable uploads can also reduce your bandwidth usage if there’s a network failure.