pub struct ContentRestriction {
pub read_only: Option<bool>,
pub reason: Option<String>,
pub restriction_type: Option<String>,
pub restricting_user: Option<User>,
pub restriction_time: Option<String>,
pub owner_restricted: Option<bool>,
pub system_restricted: Option<bool>,
}Expand description
A restriction for accessing the content of the file.
Warning:
The field type is renamed to restriction_type as the word type is a reserved keyword in Rust.
Fields
read_only: Option<bool>Whether the content of the file is read-only.
If a file is read-only, a new revision of the file may not be added, comments may not be added or modified, and the title of the file may not be modified.
reason: Option<String>Reason for why the content of the file is restricted.
This is only mutable on requests that also set readOnly=true.
restriction_type: Option<String>The type of the content restriction. Currently the only possible value is globalContentRestriction.
restricting_user: Option<User>The user who set the content restriction.
Only populated if read_only is true.
restriction_time: Option<String>The time at which the content restriction was set (formatted RFC 3339 timestamp).
Only populated if read_only is true.
owner_restricted: Option<bool>Whether the content restriction can only be modified or removed by a user who owns the file.
For files in shared drives, any user with organizer capabilities can modify or remove this content restriction.
system_restricted: Option<bool>Whether the content restriction was applied by the system, for example due to an esignature.
Users cannot modify or remove system restricted content restrictions.
Implementations