DriveInfo

Struct DriveInfo 

pub struct DriveInfo {
    pub id: Option<String>,
    pub name: Option<String>,
    pub color_rgb: Option<String>,
    pub kind: Option<String>,
    pub background_image_link: Option<String>,
    pub capabilities: Option<DriveCapabilities>,
    pub theme_id: Option<String>,
    pub background_image_file: Option<BackgroundImageFile>,
    pub created_time: Option<String>,
    pub hidden: Option<bool>,
    pub restrictions: Option<DriveRestrictions>,
    pub org_unit_id: Option<String>,
}
Representation of a shared drive.

Some resource methods (such as drives.update) require a driveId. Use the drives.list method to retrieve the ID for a shared drive.

Fields

id: Option<String>

The ID of this shared drive which is also the ID of the top level folder of this shared drive.

name: Option<String>

The name of this shared drive.

color_rgb: Option<String>

The color of this shared drive as an RGB hex string.

It can only be set on a drives.update request that does not set themeId.

kind: Option<String>

Identifies what kind of resource this is.

This is always drive#drive.

background_image_link: Option<String>

A short-lived link to this shared drive’s background image.

capabilities: Option<DriveCapabilities>

Capabilities the current user has on this shared drive.

theme_id: Option<String>

The ID of the theme from which the background image and color will be set.

The set of possible driveThemes can be retrieved from a about.get response. When not specified on a drives.create request, a random theme is chosen from which the background image and color are set. This is a write-only field; it can only be set on requests that don’t set color_rgb or background_image_file.

background_image_file: Option<BackgroundImageFile>

An image file and cropping parameters from which a background image for this shared drive is set.

This is a write only field; it can only be set on drives.update requests that don’t set theme_id. When specified, all fields of the BackgroundImageFile must be set.

created_time: Option<String>

The time at which the shared drive was created (RFC 3339 date-time).

hidden: Option<bool>

Whether the shared drive is hidden from default view.

restrictions: Option<DriveRestrictions>

A set of restrictions that apply to this shared drive or items inside this shared drive.

Note that restrictions can’t be set when creating a shared drive. To add a restriction, first create a shared drive and then use drives.update to add restrictions.

org_unit_id: Option<String>

The organizational unit of this shared drive.

This field is only populated on drives.list responses when the useDomainAdminAccess parameter is set to true.

Implementations

Source

impl DriveInfo

pub fn new() -> Self

Creates a new, empty instance of this struct.