FileList

Struct FileList 

pub struct FileList {
    pub next_page_token: Option<String>,
    pub kind: Option<String>,
    pub incomplete_search: Option<bool>,
    pub files: Option<Vec<File>>,
}
List of the user’s files.

Note

All of the fields of FileList are an Option<T> since the values that Google’s API will return are dependent on the fields requested, by default all fields will be requested but if you change this value only the specified fields will be Some<T>, the rest will be None.

Fields

next_page_token: Option<String>

The page token for the next page of files.

This will be absent if the end of the files list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. The page token is typically valid for several hours. However, if new items are added or removed, your expected results might differ.

kind: Option<String>

Identifies what kind of resource this is. Value: the fixed string “drive#fileList”.

incomplete_search: Option<bool>

Whether the search process was incomplete.

If true, then some search results might be missing, since all documents were not searched. This can occur when searching multiple drives with the allDrives corpora, but all corpora couldn’t be searched. When this happens, it’s suggested that clients narrow their query by choosing a different corpus such as user or drive.

files: Option<Vec<File>>

The list of files.

If next_page_token is populated, then this list may be incomplete and an additional page of results should be fetched.

Implementations

Source

impl FileList

pub fn new() -> Self

Creates a new, empty instance of this struct.