pub struct ListRequest { /* private fields */ }Expand description
A request builder to list a user’s installed apps.
Implementations
Sourceimpl ListRequest
impl ListRequest
Sourcepub fn new(credentials: &Credentials) -> Self
pub fn new(credentials: &Credentials) -> Self
Creates a new ListRequest builder, authorized with the given Credentials.
Sourcepub fn execute(&self) -> Result<AppList>
pub fn execute(&self) -> Result<AppList>
Executes this request.
Errors:
- a
UrlParsingerror, if the creation of the request’s URL failed. - a
Requesterror, if unable to send the request or get a body from the response. - a
Responseerror, if the request returned an error response. - a
Jsonerror, if unable to parse the response’s body to into the return type.
Sourcepub fn fields<T>(self, value: T) -> Self
pub fn fields<T>(self, value: T) -> Self
You can set this parameter to return the exact fields you need, and improve performance in your method call.
Note:
By default, the server sends back a set of fields specific to the resource being queried. For example, the files.get method might only return the id, name, and mimeType for the files resource. The permissions.get method returns a different set of default fields for a permissions resource.
See Google’s documentation
Sourcepub fn app_filter_extensions<T>(self, value: T) -> Self
pub fn app_filter_extensions<T>(self, value: T) -> Self
A comma-separated list of file extensions to limit returned results.
All results within the given app query scope which can open any of
the given file extensions are included in the response. If
app_filter_mime_types are
provided as well, the result is a union of the two resulting app
lists.
Sourcepub fn app_filter_mime_types<T>(self, value: T) -> Self
pub fn app_filter_mime_types<T>(self, value: T) -> Self
A comma-separated list of file extensions to limit returned results.
All results within the given app query scope which can open any of
the given MIME types will be included in the response. If
app_filter_extensions are
provided as well, the result is a union of the two resulting app
lists.
Sourcepub fn language_code<T>(self, value: T) -> Self
pub fn language_code<T>(self, value: T) -> Self
A language or locale code, as defined by BCP 47, with some extensions from Unicode’s LDML format.