pub struct ListRequest { /* private fields */ }Expand description
A request builder to list the changes for a user or drive.
Implementations
Sourceimpl ListRequest
impl ListRequest
Sourcepub fn new(credentials: &Credentials) -> Self
pub fn new(credentials: &Credentials) -> Self
Creates a new ListRequest builder, authorized with the given Credentials.
Sourcepub fn execute(&self) -> Result<ChangeList>
pub fn execute(&self) -> Result<ChangeList>
Executes this request.
Errors:
- a
UrlParsingerror, if the creation of the request’s URL failed. - a
Requesterror, if unable to send the request or get a body from the response. - a
Responseerror, if the request returned an error response. - a
Jsonerror, if unable to parse the response’s body to into the return type.
Sourcepub fn fields<T>(self, value: T) -> Self
pub fn fields<T>(self, value: T) -> Self
You can set this parameter to return the exact fields you need, and improve performance in your method call.
Note:
By default, the server sends back a set of fields specific to the resource being queried. For example, the files.get method might only return the id, name, and mimeType for the files resource. The permissions.get method returns a different set of default fields for a permissions resource.
See Google’s documentation
Sourcepub fn drive_id<T>(self, value: T) -> Self
pub fn drive_id<T>(self, value: T) -> Self
The shared drive from which changes will be returned.
If specified the change IDs will be reflective of the shared drive; use the combined drive ID and change ID as an identifier.
Sourcepub fn include_corpus_removals<T>(self, value: T) -> Self
pub fn include_corpus_removals<T>(self, value: T) -> Self
Whether changes should include the file resource if the file is still accessible by the user at the time of the request, even when a file was removed from the list of changes and there will be no further change entries for this file.
Sourcepub fn include_items_from_all_drives<T>(self, value: T) -> Self
pub fn include_items_from_all_drives<T>(self, value: T) -> Self
Whether both My Drive and shared drive items should be included in results.
Sourcepub fn include_removed<T>(self, value: T) -> Self
pub fn include_removed<T>(self, value: T) -> Self
Whether to include changes indicating that items have been removed from the list of changes, for example by deletion or loss of access.
Sourcepub fn page_token<T>(self, value: T) -> Self
pub fn page_token<T>(self, value: T) -> Self
The token for continuing a previous list request on the next page.
This should be set to the value of
next_page_token from the
previous response or to the response from the
get_start_page_token method.
Sourcepub fn restrict_to_my_drive<T>(self, value: T) -> Self
pub fn restrict_to_my_drive<T>(self, value: T) -> Self
Whether to restrict the results to changes inside the My Drive hierarchy.
This omits changes to files such as those in the Application Data folder or shared files which have not been added to My Drive.
Sourcepub fn spaces<T>(self, value: T) -> Self
pub fn spaces<T>(self, value: T) -> Self
A comma-separated list of spaces to query within the corpora.
Supported values are drive and appDataFolder.
Sourcepub fn supports_all_drives<T>(self, value: T) -> Self
pub fn supports_all_drives<T>(self, value: T) -> Self
Whether the requesting application supports both My Drives and shared drives.
Sourcepub fn include_permissions_for_view<T>(self, value: T) -> Self
pub fn include_permissions_for_view<T>(self, value: T) -> Self
Specifies which additional view’s permissions to include in the response.
Only published is supported.
Sourcepub fn include_labels<T>(self, value: T) -> Self
pub fn include_labels<T>(self, value: T) -> Self
A comma-separated list of IDs of labels to include in the
label_info part of the response.