pub struct About { /* private fields */ }Expand description
Information about the user, the user’s Drive, and system capabilities.
Examples:
use drive_v3::{Credentials, Drive};
let credentials_path = "my_credentials.json";
let scopes = ["https://www.googleapis.com/auth/drive.metadata.readonly"];
let credentials = Credentials::from_file(&credentials_path, &scopes)?;
let drive = Drive::new(&credentials);
let my_information = drive.about.get()
.fields("storageQuota, canCreateDrives, appInstalled")
.execute()?;
println!("look at all this information:\n{}", my_information);Implementations
Sourceimpl About
impl About
Sourcepub fn new(credentials: &Credentials) -> Self
pub fn new(credentials: &Credentials) -> Self
Creates a new About resource with the given Credentials.
Sourcepub fn get(&self) -> GetRequest
pub fn get(&self) -> GetRequest
Gets information about the user, the user’s Drive, and system capabilities.
See Google’s documentation for more information.
Note:
This request requires you to set the fields parameter.
Requires one of the following OAuth scopes:
https://www.googleapis.com/auth/drivehttps://www.googleapis.com/auth/drive.appdatahttps://www.googleapis.com/auth/drive.filehttps://www.googleapis.com/auth/drive.metadatahttps://www.googleapis.com/auth/drive.metadata.readonlyhttps://www.googleapis.com/auth/drive.photos.readonlyhttps://www.googleapis.com/auth/drive.readonly
Examples:
use drive_v3::{Credentials, Drive};
let credentials_path = "my_credentials.json";
let scopes = ["https://www.googleapis.com/auth/drive.metadata.readonly"];
let credentials = Credentials::from_file(&credentials_path, &scopes)?;
let drive = Drive::new(&credentials);
let my_information = drive.about.get()
.fields("storageQuota, canCreateDrives, appInstalled")
.execute()?;
println!("look at all this information:\n{}", my_information);Trait Implementations
impl Eq for About
impl StructuralPartialEq for About