pub struct Channels { /* private fields */ }Expand description
A notification channel used to watch for resource changes.
Examples:
use drive_v3::objects::Channel;
// You should use the channel return by requests like files.watch or
// changes.watch
let channel = Channel::new();
let response = drive.channels.stop()
.channel(&channel)
.execute();
assert!( response.is_ok() );Implementations
Sourceimpl Channels
impl Channels
Sourcepub fn new(credentials: &Credentials) -> Self
pub fn new(credentials: &Credentials) -> Self
Creates a new Channels resource with the given Credentials.
Sourcepub fn stop(&self) -> StopRequest
pub fn stop(&self) -> StopRequest
Stops watching resources through this channel.
See Google’s documentation for more information.
Requires one of the following OAuth scopes:
https://www.googleapis.com/auth/docshttps://www.googleapis.com/auth/drivehttps://www.googleapis.com/auth/drive.appdatahttps://www.googleapis.com/auth/drive.appshttps://www.googleapis.com/auth/drive.filehttps://www.googleapis.com/auth/drive.metadatahttps://www.googleapis.com/auth/drive.metadata.readonlyhttps://www.googleapis.com/auth/drive.photos.readonlyhttps://www.googleapis.com/auth/drive.readonly
Examples:
use drive_v3::objects::Channel;
// You should use the channel return by requests like files.watch or
// changes.watch
let channel = Channel::new();
let response = drive.channels.stop()
.channel(&channel)
.execute();
assert!( response.is_ok() );Trait Implementations
impl Eq for Channels
impl StructuralPartialEq for Channels